summaryrefslogtreecommitdiff
path: root/decoder/ff.h
diff options
context:
space:
mode:
authorgraehl <graehl@ec762483-ff6d-05da-a07a-a48fb63a330f>2010-07-24 21:18:01 +0000
committergraehl <graehl@ec762483-ff6d-05da-a07a-a48fb63a330f>2010-07-24 21:18:01 +0000
commit2cb224de7db49b761ac06b031090fe7f846744fe (patch)
treedc1d4e949081ea0e0868773bd7a31b96faa77487 /decoder/ff.h
parent1fbdaa4d49acf90d2124aef8810d723ddbb0dad5 (diff)
FSA: simpler Scan1 ScanT1 methods, otherewise also expose edge to full Scan
git-svn-id: https://ws10smt.googlecode.com/svn/trunk@399 ec762483-ff6d-05da-a07a-a48fb63a330f
Diffstat (limited to 'decoder/ff.h')
-rw-r--r--decoder/ff.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/decoder/ff.h b/decoder/ff.h
index 9ff67dd8..b8ca71c4 100644
--- a/decoder/ff.h
+++ b/decoder/ff.h
@@ -64,8 +64,9 @@ protected:
virtual void FinalTraversalFeatures(const void* residual_state,
FeatureVector* final_features) const;
public:
- //override either this or above. (no need to do both)
- virtual void FinalTraversalFeatures(const SentenceMetadata& smeta,
+ //override either this or one of above.
+ virtual void FinalTraversalFeatures(const SentenceMetadata& /* smeta */,
+ const Hypergraph::Edge& /* edge */,
const void* residual_state,
FeatureVector* final_features) const {
FinalTraversalFeatures(residual_state,final_features);